@@ -8,6 +8,7 @@ import os
 import platform
 import stat
 import subprocess
+import warnings
 from threading import Lock
 from uuid import uuid4
 
@@ -21,6 +22,7 @@ from sklearn.utils.multiclass import check_classification_targets
 from sklearn.utils.validation import check_array, check_consistent_length, check_X_y, column_or_1d
 
 
+CURRENT_DIR = os.path.dirname(__file__)
 FLOATS = (float, np.float, np.float16, np.float32, np.float64, np.double)
 INTS = (numbers.Integral, np.integer)
 NOT_FITTED_ERROR_DESC = "Estimator not fitted, call `fit` before exploiting the model."
@@ -67,34 +69,33 @@ def get_paths():
             rgf_exe = os.path.abspath(config.get(config.sections()[0], 'exe_location'))
         except Exception:
             rgf_exe = os.path.join(os.path.expanduser('~'), 'rgf.exe')
-        try:
-            fast_rgf_path = os.path.abspath(config.get(config.sections()[0], 'fastrgf_location'))
-        except Exception:
-            fast_rgf_path = os.path.expanduser('~')
         try:
             temp = os.path.abspath(config.get(config.sections()[0], 'temp_location'))
         except Exception:
             temp = os.path.join(os.path.expanduser('~'), 'temp', 'rgf')
-        def_exe = 'rgf.exe'
-    else:  # Linux, Darwin (OS X), etc.
+        def_rgf = 'rgf.exe'
+    else:  # Linux, Darwin (macOS), etc.
         try:
             rgf_exe = os.path.abspath(config.get(config.sections()[0], 'exe_location'))
         except Exception:
             rgf_exe = os.path.join(os.path.expanduser('~'), 'rgf')
-        try:
-            fast_rgf_path = os.path.abspath(config.get(config.sections()[0], 'fastrgf_location'))
-        except Exception:
-            fast_rgf_path = os.path.expanduser('~')
         try:
             temp = os.path.abspath(config.get(config.sections()[0], 'temp_location'))
         except Exception:
             temp = os.path.join('/tmp', 'rgf')
-        def_exe = 'rgf'
+        def_rgf = 'rgf'
 
-    return def_exe, rgf_exe, fast_rgf_path, temp
+    try:
+        fastrgf_path = os.path.abspath(config.get(config.sections()[0], 'fastrgf_location'))
+    except Exception:
+        fastrgf_path = os.path.expanduser('~')
+
+    def_fastrgf = ''
+
+    return def_rgf, rgf_exe, def_fastrgf, fastrgf_path, temp
 
 
-DEFAULT_EXE_PATH, EXE_PATH, FASTRGF_PATH, TEMP_PATH = get_paths()
+DEFAULT_RGF_PATH, RGF_PATH, DEFAULT_FASTRGF_PATH, FASTRGF_PATH, TEMP_PATH = get_paths()
 
 
 if not os.path.isdir(TEMP_PATH):
@@ -108,7 +109,7 @@ def is_rgf_executable(path):
     temp_x_loc = os.path.join(TEMP_PATH, 'temp_rgf.train.data.x')
     temp_y_loc = os.path.join(TEMP_PATH, 'temp_rgf.train.data.y')
     temp_model_loc = os.path.join(TEMP_PATH, 'temp_rgf.model')
-    temp_pred_loc = os.path.join(TEMP_PATH, "temp_rgf.predictions.txt")
+    temp_pred_loc = os.path.join(TEMP_PATH, 'temp_rgf.predictions.txt')
     np.savetxt(temp_x_loc, [[1, 0, 1, 0], [0, 1, 0, 1]], delimiter=' ', fmt="%s")
     np.savetxt(temp_y_loc, [1, -1], delimiter=' ', fmt="%s")
     UUIDS.append('temp_rgf')
@@ -117,6 +118,7 @@ def is_rgf_executable(path):
     params_train.append("train_y_fn=%s" % temp_y_loc)
     params_train.append("model_fn_prefix=%s" % temp_model_loc)
     params_train.append("reg_L2=%s" % 1)
+    params_train.append("max_leaf_forest=%s" % 10)
     params_pred = []
     params_pred.append("test_x_fn=%s" % temp_x_loc)
     params_pred.append("prediction_fn=%s" % temp_pred_loc)
@@ -126,8 +128,10 @@ def is_rgf_executable(path):
     except Exception:
         pass
     try:
-        subprocess.check_output((path, "train", ",".join(params_train)))
-        subprocess.check_output((path, "predict", ",".join(params_pred)))
+        subprocess.check_output((path, "train", ",".join(params_train)),
+                                stderr=subprocess.STDOUT)
+        subprocess.check_output((path, "predict", ",".join(params_pred)),
+                                stderr=subprocess.STDOUT)
         return True
     except Exception:
         return False
@@ -138,13 +142,15 @@ def is_fastrgf_executable(path):
     temp_y_loc = os.path.join(TEMP_PATH, 'temp_fastrgf.train.data.y')
     temp_model_loc = os.path.join(TEMP_PATH, "temp_fastrgf.model")
     temp_pred_loc = os.path.join(TEMP_PATH, "temp_fastrgf.predictions.txt")
-    X = np.tile(np.array([[1, 0, 1, 0], [0, 1, 0, 1]]), (15, 1))
-    y = np.tile(np.array([1, -1]), (15, 1))
+    X = np.tile(np.array([[1, 0, 1, 0], [0, 1, 0, 1]]), (14, 1))
+    y = np.tile(np.array([1, -1]), 14)
     np.savetxt(temp_x_loc, X, delimiter=' ', fmt="%s")
     np.savetxt(temp_y_loc, y, delimiter=' ', fmt="%s")
     UUIDS.append('temp_fastrgf')
     path_train = os.path.join(path, "forest_train")
     params_train = []
+    params_train.append("forest.ntrees=%s" % 10)
+    params_train.append("tst.target=%s" % "BINARY")
     params_train.append("trn.x-file=%s" % temp_x_loc)
     params_train.append("trn.y-file=%s" % temp_y_loc)
     params_train.append("model.save=%s" % temp_model_loc)
@@ -163,35 +169,34 @@ def is_fastrgf_executable(path):
     except Exception:
         pass
     try:
-        subprocess.check_output(cmd_train)
-        subprocess.check_output(cmd_pred)
+        subprocess.check_output(cmd_train, stderr=subprocess.STDOUT)
+        subprocess.check_output(cmd_pred, stderr=subprocess.STDOUT)
     except Exception:
         return False
     return True
 
 
-if is_rgf_executable(DEFAULT_EXE_PATH):
-    EXE_PATH = DEFAULT_EXE_PATH
-elif is_rgf_executable(os.path.join(os.path.dirname(__file__), DEFAULT_EXE_PATH)):
-    EXE_PATH = os.path.join(os.path.dirname(__file__), DEFAULT_EXE_PATH)
-elif not os.path.isfile(EXE_PATH):
-    raise Exception("{0} is not executable file. Please set "
-                    "config flag 'exe_location' to RGF execution file.".format(EXE_PATH))
-elif not os.access(EXE_PATH, os.X_OK):
-    raise Exception("{0} cannot be accessed. Please set "
-                    "config flag 'exe_location' to RGF execution file.".format(EXE_PATH))
-elif is_rgf_executable(EXE_PATH):
+RGF_AVAILABLE = True
+if is_rgf_executable(os.path.join(CURRENT_DIR, DEFAULT_RGF_PATH)):
+    RGF_PATH = os.path.join(CURRENT_DIR, DEFAULT_RGF_PATH)
+elif is_rgf_executable(DEFAULT_RGF_PATH):
+    RGF_PATH = DEFAULT_RGF_PATH
+elif is_rgf_executable(RGF_PATH):
     pass
 else:
-    raise Exception("{0} does not exist or {1} is not in the "
-                    "'PATH' variable.".format(EXE_PATH, DEFAULT_EXE_PATH))
+    RGF_AVAILABLE = False
+    warnings.warn("Cannot find RGF executable file. RGF estimators will be unavailable for usage.")
 
-FASTRGF_AVAILABLE = False
-if is_fastrgf_executable(FASTRGF_PATH):
-    FASTRGF_AVAILABLE = True
-elif is_fastrgf_executable(os.path.dirname(__file__)):
-    FASTRGF_PATH = os.path.dirname(__file__)
-    FASTRGF_AVAILABLE = True
+FASTRGF_AVAILABLE = True
+if is_fastrgf_executable(CURRENT_DIR):
+    FASTRGF_PATH = CURRENT_DIR
+elif is_fastrgf_executable(DEFAULT_FASTRGF_PATH):
+    FASTRGF_PATH = DEFAULT_FASTRGF_PATH
+elif is_fastrgf_executable(FASTRGF_PATH):
+    pass
+else:
+    FASTRGF_AVAILABLE = False
+    warnings.warn("Cannot find FastRGF executable files. FastRGF estimators will be unavailable for usage.")
 
 
 class AtomicCounter(object):
@@ -212,7 +217,7 @@ def sparse_savetxt(filename, input_array, including_header=True):
     zip_func = six.moves.zip
     if sp.isspmatrix_csr(input_array):
         input_array = input_array.tocoo()
-    elif not sp.isspmatrix_coo(input_array):
+    else:
         input_array = input_array.tocsr().tocoo()
     n_row = input_array.shape[0]
     current_sample_row = 0
@@ -240,7 +245,7 @@ def fit_ovr_binary(binary_clf, X, y, sample_weight):
     return binary_clf.fit(X, y, sample_weight)
 
 
-class RGFRegressorBase(BaseEstimator, RegressorMixin):
+class RGFMixin(object):
     @property
     def n_features_(self):
         """The number of features when `fit` is performed."""
@@ -257,6 +262,108 @@ class RGFRegressorBase(BaseEstimator, RegressorMixin):
         else:
             return self._fitted
 
+    def _get_sample_weight(self, sample_weight):
+        if sample_weight is not None:
+            sample_weight = column_or_1d(sample_weight, warn=True)
+            if (sample_weight <= 0).any():
+                raise ValueError("Sample weights must be positive.")
+        return sample_weight
+
+    def _set_paths(self):
+        self._train_x_loc = os.path.join(TEMP_PATH, self._file_prefix + ".train.data.x")
+        self._test_x_loc = os.path.join(TEMP_PATH, self._file_prefix + ".test.data.x")
+        self._train_y_loc = os.path.join(TEMP_PATH, self._file_prefix + ".train.data.y")
+        self._train_weight_loc = os.path.join(TEMP_PATH, self._file_prefix + ".train.data.weight")
+        self._model_file_loc = os.path.join(TEMP_PATH, self._file_prefix + ".model")
+        self._pred_loc = os.path.join(TEMP_PATH, self._file_prefix + ".predictions.txt")
+
+    def _save_train_data(self, X, y, sample_weight):
+        if sample_weight is None:
+            self._use_sample_weight = False
+        else:
+            self._use_sample_weight = True
+
+        if sp.isspmatrix(X):
+            self._save_sparse_X(self._train_x_loc, X)
+            np.savetxt(self._train_y_loc, y, delimiter=' ', fmt="%s")
+            if self._use_sample_weight:
+                np.savetxt(self._train_weight_loc, sample_weight, delimiter=' ', fmt="%s")
+            self._is_sparse_train_X = True
+        else:
+            self._save_dense_files(X, y, sample_weight)
+            self._is_sparse_train_X = False
+
+    def _execute_command(self, cmd):
+        output = subprocess.Popen(cmd,
+                                  stdout=subprocess.PIPE,
+                                  stderr=subprocess.STDOUT,
+                                  universal_newlines=True).communicate()
+
+        if self.verbose:
+            for k in output:
+                print(k)
+
+    def _check_fitted(self):
+        if self._fitted is None:
+            raise NotFittedError(NOT_FITTED_ERROR_DESC)
+        if not os.path.isfile(self._model_file):
+            raise Exception('Model learning result is not found in {0}. '
+                            'This is rgf_python error.'.format(TEMP_PATH))
+
+    def _check_n_features(self, n_features):
+        if self._n_features != n_features:
+            raise ValueError("Number of features of the model must "
+                             "match the input. Model n_features is %s and "
+                             "input n_features is %s "
+                             % (self._n_features, n_features))
+
+    def _save_test_X(self, X):
+        if sp.isspmatrix(X):
+            self._save_sparse_X(self._test_x_loc, X)
+            is_sparse_test_X = True
+        else:
+            np.savetxt(self._test_x_loc, X, delimiter=' ', fmt="%s")
+            is_sparse_test_X = False
+
+        return is_sparse_test_X
+
+    def _validate_params(self, params):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def _set_params_with_dependencies(self):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def _save_sparse_X(self, path, X):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def _save_dense_files(self, X, y, sample_weight):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def _find_model_file(self):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def _get_train_command(self):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def _get_test_command(self, is_sparse_test_X):
+        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
+
+    def __getstate__(self):
+        state = self.__dict__.copy()
+        if hasattr(self, "_model_file") and self._fitted:
+            with open(self._model_file, 'rb') as fr:
+                state["model"] = fr.read()
+        return state
+
+    def __setstate__(self, state):
+        self.__dict__.update(state)
+        if hasattr(self, "_model_file") and self._fitted:
+            with open(self._model_file, 'wb') as fw:
+                fw.write(self.__dict__["model"])
+            del self.__dict__["model"]
+
+
+class RGFRegressorBase(RGFMixin, BaseEstimator, RegressorMixin):
     def fit(self, X, y, sample_weight=None):
         """
         Build a regressor from the training set (X, y).
@@ -281,47 +388,18 @@ class RGFRegressorBase(BaseEstimator, RegressorMixin):
 
         X, y = check_X_y(X, y, accept_sparse=True, multi_output=False, y_numeric=True)
         self._n_samples, self._n_features = X.shape
-
-        if sample_weight is None:
-            sample_weight = np.ones(self._n_samples, dtype=np.float32)
-        else:
-            sample_weight = column_or_1d(sample_weight, warn=True)
-            if (sample_weight <= 0).any():
-                raise ValueError("Sample weights must be positive.")
+        sample_weight = self._get_sample_weight(sample_weight)
         check_consistent_length(X, y, sample_weight)
 
-        self._train_x_loc = os.path.join(TEMP_PATH, self._file_prefix + ".train.data.x")
-        self._test_x_loc = os.path.join(TEMP_PATH, self._file_prefix + ".test.data.x")
-        self._train_y_loc = os.path.join(TEMP_PATH, self._file_prefix + ".train.data.y")
-        self._train_weight_loc = os.path.join(TEMP_PATH, self._file_prefix + ".train.data.weight")
-        self._model_file_loc = os.path.join(TEMP_PATH, self._file_prefix + ".model")
-        self._pred_loc = os.path.join(TEMP_PATH, self._file_prefix + ".predictions.txt")
-
-        if sp.isspmatrix(X):
-            self._save_sparse_X(self._train_x_loc, X)
-            np.savetxt(self._train_y_loc, y, delimiter=' ', fmt="%s")
-            np.savetxt(self._train_weight_loc, sample_weight, delimiter=' ', fmt="%s")
-            self._is_sparse_train_X = True
-        else:
-            self._save_dense_files(X, y, sample_weight)
-            self._is_sparse_train_X = False
+        self._set_paths()
+        self._save_train_data(X, y, sample_weight)
 
         self._set_params_with_dependencies()
 
         cmd = self._get_train_command()
-
-        # Train
-        output = subprocess.Popen(cmd,
-                                  stdout=subprocess.PIPE,
-                                  stderr=subprocess.STDOUT,
-                                  universal_newlines=True).communicate()
-
-        if self.verbose:
-            for k in output:
-                print(k)
+        self._execute_command(cmd)
 
         self._find_model_file()
-
         self._fitted = True
 
         return self
@@ -342,37 +420,14 @@ class RGFRegressorBase(BaseEstimator, RegressorMixin):
         y : array of shape = [n_samples]
             The predicted values.
         """
-        if self._fitted is None:
-            raise NotFittedError(NOT_FITTED_ERROR_DESC)
-        if not os.path.isfile(self._model_file):
-            raise Exception('Model learning result is not found in {0}. '
-                            'This is rgf_python error.'.format(TEMP_PATH))
+        self._check_fitted()
 
         X = check_array(X, accept_sparse=True)
-        n_features = X.shape[1]
-        if self._n_features != n_features:
-            raise ValueError("Number of features of the model must "
-                             "match the input. Model n_features is %s and "
-                             "input n_features is %s "
-                             % (self._n_features, n_features))
-
-        if sp.isspmatrix(X):
-            self._save_sparse_X(self._test_x_loc, X)
-            is_sparse_test_X = True
-        else:
-            np.savetxt(self._test_x_loc, X, delimiter=' ', fmt="%s")
-            is_sparse_test_X = False
+        self._check_n_features(X.shape[1])
+        is_sparse_test_X = self._save_test_X(X)
 
         cmd = self._get_test_command(is_sparse_test_X)
-
-        output = subprocess.Popen(cmd,
-                                  stdout=subprocess.PIPE,
-                                  stderr=subprocess.STDOUT,
-                                  universal_newlines=True).communicate()
-
-        if self.verbose:
-            for k in output:
-                print(k)
+        self._execute_command(cmd)
 
         return np.loadtxt(self._pred_loc)
 
@@ -389,43 +444,8 @@ class RGFRegressorBase(BaseEstimator, RegressorMixin):
         self._fitted = None
         return cleanup_partial(self._file_prefix, remove_from_list=True)
 
-    def _validate_params(self, params):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
 
-    def _set_params_with_dependencies(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def _get_train_command(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def _get_test_command(self, is_sparse_x):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def _save_sparse_X(self, path, X):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def _save_dense_files(self, X, y, sample_weight):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def _find_model_file(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def __getstate__(self):
-        state = self.__dict__.copy()
-        if self._fitted:
-            with open(self._model_file, 'rb') as fr:
-                state["model"] = fr.read()
-        return state
-
-    def __setstate__(self, state):
-        self.__dict__.update(state)
-        if self._fitted:
-            with open(self._model_file, 'wb') as fw:
-                fw.write(self.__dict__["model"])
-            del self.__dict__["model"]
-
-
-class RGFClassifierBase(BaseEstimator, ClassifierMixin):
+class RGFClassifierBase(RGFMixin, BaseEstimator, ClassifierMixin):
     @property
     def estimators_(self):
         """The collection of fitted sub-estimators when `fit` is performed."""
@@ -450,22 +470,6 @@ class RGFClassifierBase(BaseEstimator, ClassifierMixin):
         else:
             return self._n_classes
 
-    @property
-    def n_features_(self):
-        """The number of features when `fit` is performed."""
-        if self._n_features is None:
-            raise NotFittedError(NOT_FITTED_ERROR_DESC)
-        else:
-            return self._n_features
-
-    @property
-    def fitted_(self):
-        """Indicates whether `fit` is performed."""
-        if self._fitted is None:
-            raise NotFittedError(NOT_FITTED_ERROR_DESC)
-        else:
-            return self._fitted
-
     def fit(self, X, y, sample_weight=None):
         """
         Build a classifier from the training set (X, y).
@@ -494,13 +498,7 @@ class RGFClassifierBase(BaseEstimator, ClassifierMixin):
         else:
             self._is_sparse_train_X = False
         self._n_samples, self._n_features = X.shape
-
-        if sample_weight is None:
-            sample_weight = np.ones(self._n_samples, dtype=np.float32)
-        else:
-            sample_weight = column_or_1d(sample_weight, warn=True)
-            if (sample_weight <= 0).any():
-                raise ValueError("Sample weights must be positive.")
+        sample_weight = self._get_sample_weight(sample_weight)
         check_consistent_length(X, y, sample_weight)
         check_classification_targets(y)
 
@@ -508,7 +506,6 @@ class RGFClassifierBase(BaseEstimator, ClassifierMixin):
         self._n_classes = len(self._classes)
 
         self._set_params_with_dependencies()
-
         params = self._get_params()
 
         if self._n_classes == 2:
@@ -549,12 +546,8 @@ class RGFClassifierBase(BaseEstimator, ClassifierMixin):
         if self._fitted is None:
             raise NotFittedError(NOT_FITTED_ERROR_DESC)
         X = check_array(X, accept_sparse=True)
-        n_features = X.shape[1]
-        if self._n_features != n_features:
-            raise ValueError("Number of features of the model must "
-                             "match the input. Model n_features is %s and "
-                             "input n_features is %s "
-                             % (self._n_features, n_features))
+        self._check_n_features(X.shape[1])
+
         if self._n_classes == 2:
             y = self._estimators[0].predict_proba(X)
             y = sigmoid(y)
@@ -608,19 +601,13 @@ class RGFClassifierBase(BaseEstimator, ClassifierMixin):
         n_removed_files = 0
         if self._estimators is not None:
             for est in self._estimators:
-                n_removed_files += cleanup_partial(est.file_prefix,
+                n_removed_files += cleanup_partial(est._file_prefix,
                                                    remove_from_list=True)
 
         # No more able to predict without refitting.
         self._fitted = None
         return n_removed_files
 
-    def _validate_params(self, params):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def _set_params_with_dependencies(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
     def _get_params(self):
         raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
 
@@ -631,105 +618,37 @@ class RGFClassifierBase(BaseEstimator, ClassifierMixin):
         raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
 
 
-class RGFBinaryClassifierBase(BaseEstimator, ClassifierMixin):
+class RGFBinaryClassifierBase(RGFMixin, BaseEstimator, ClassifierMixin):
     def __init__(self, **kwargs):
         for key, value in kwargs.items():
             setattr(self, key, value)
 
-        self.file_prefix = str(uuid4()) + str(COUNTER.increment())
-        UUIDS.append(self.file_prefix)
-        self.fitted = None
+        self._file_prefix = str(uuid4()) + str(COUNTER.increment())
+        UUIDS.append(self._file_prefix)
+        self._fitted = None
 
     def fit(self, X, y, sample_weight):
-        self.train_x_loc = os.path.join(TEMP_PATH, self.file_prefix + ".train.data.x")
-        self.test_x_loc = os.path.join(TEMP_PATH, self.file_prefix + ".test.data.x")
-        self.train_y_loc = os.path.join(TEMP_PATH, self.file_prefix + ".train.data.y")
-        self.train_weight_loc = os.path.join(TEMP_PATH, self.file_prefix + ".train.data.weight")
-        self.model_file_loc = os.path.join(TEMP_PATH, self.file_prefix + ".model")
-        self.pred_loc = os.path.join(TEMP_PATH, self.file_prefix + ".predictions.txt")
+        self._set_paths()
 
         # Convert 1 to 1, 0 to -1
         y = 2 * y - 1
 
-        if sp.isspmatrix(X):
-            self.save_sparse_X(self.train_x_loc, X)
-            np.savetxt(self.train_y_loc, y, delimiter=' ', fmt="%s")
-            np.savetxt(self.train_weight_loc, sample_weight, delimiter=' ', fmt="%s")
-            self.is_sparse_train_X = True
-        else:
-            self.save_dense_files(X, y, sample_weight)
-            self.is_sparse_train_X = False
+        self._save_train_data(X, y, sample_weight)
 
-        cmd = self.get_train_command()
+        cmd = self._get_train_command()
+        self._execute_command(cmd)
 
-        # Train
-        output = subprocess.Popen(cmd,
-                                  stdout=subprocess.PIPE,
-                                  stderr=subprocess.STDOUT,
-                                  universal_newlines=True).communicate()
-
-        if self.verbose:
-            for k in output:
-                print(k)
-
-        self.find_model_file()
-
-        self.fitted = True
+        self._find_model_file()
+        self._fitted = True
 					        
         return self
 
     def predict_proba(self, X):
-        if self.fitted is None:
-            raise NotFittedError(NOT_FITTED_ERROR_DESC)
-        if not os.path.isfile(self.model_file):
-            raise Exception('Model learning result is not found in {0}. '
-                            'This is rgf_python error.'.format(TEMP_PATH))
+        self._check_fitted()
 
-        if sp.isspmatrix(X):
-            self.save_sparse_X(self.test_x_loc, X)
-            self.is_sparse_test_X = True
-        else:
-            np.savetxt(self.test_x_loc, X, delimiter=' ', fmt="%s")
-            self.is_sparse_test_X = False
+        is_sparse_test_X = self._save_test_X(X)
 
-        cmd = self.get_test_command()
+        cmd = self._get_test_command(is_sparse_test_X)
+        self._execute_command(cmd)
 
-        output = subprocess.Popen(cmd,
-                                  stdout=subprocess.PIPE,
-                                  stderr=subprocess.STDOUT,
-                                  universal_newlines=True).communicate()
-
-        if self.verbose:
-            for k in output:
-                print(k)
-
-        return np.loadtxt(self.pred_loc)
-
-    def save_sparse_X(self, X):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def save_dense_files(self, X, y, sample_weight):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def get_train_command(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def find_model_file(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def get_test_command(self):
-        raise NotImplementedError(NOT_IMPLEMENTED_ERROR_DESC)
-
-    def __getstate__(self):
-        state = self.__dict__.copy()
-        if self.fitted:
-            with open(self.model_file, 'rb') as fr:
-                state["model"] = fr.read()
-        return state
-
-    def __setstate__(self, state):
-        self.__dict__.update(state)
-        if self.fitted:
-            with open(self.model_file, 'wb') as fw:
-                fw.write(self.__dict__["model"])
-            del self.__dict__["model"]
+        return np.loadtxt(self._pred_loc)
